@@ -1,7 +1,7 @@
 ;;;; -*- Mode: LISP; Syntax: ANSI-Common-Lisp; Base: 10 -*-
 ;;;; *************************************************************************
 ;;;;
-;;;; $Id: transaction.lisp 10975 2006-07-07 19:01:59Z kevin $
+;;;; $Id$
 ;;;;
 ;;;; Transaction support
 ;;;;
@@ -18,9 +18,9 @@
   ((commit-hooks :initform () :accessor commit-hooks)
    (rollback-hooks :initform () :accessor rollback-hooks)
    (previous-autocommit :initarg :previous-autocommit
-			:reader previous-autocommit)
+                        :reader previous-autocommit)
    (status :initform nil :accessor transaction-status
-	   :documentation "nil or :committed")))
+           :documentation "nil or :committed")))
 
 (defun add-transaction-commit-hook (commit-hook &key
                                     (database *default-database*))
@@ -41,8 +41,8 @@ is called on DATABASE which defaults to *DEFAULT-DATABASE*."
 (defmethod database-start-transaction ((database database))
   (unless (transaction database)
     (setf (transaction database)
-	  (make-instance 'transaction :previous-autocommit
-			 (database-autocommit database))))
+          (make-instance 'transaction :previous-autocommit
+                         (database-autocommit database))))
   (setf (database-autocommit database) nil)
   (when (= (incf (transaction-level database)) 1)
     (let ((transaction (transaction database)))
@@ -54,30 +54,37 @@ is called on DATABASE which defaults to *DEFAULT-DATABASE*."
         (:mssql (execute-command "BEGIN TRANSACTION" :database database))
         (t (execute-command "BEGIN" :database database))))))
 
+;;ODBC should potentially be using it's scheme for transactions:
+;; turn off autocommit for begin. then use sqlendtran (or maybe sqltransact)
+;; whatever is appropriate for this version of odbc.
 (defmethod database-commit-transaction ((database database))
   (with-slots (transaction transaction-level autocommit) database
     (if (plusp transaction-level)
         (when (zerop (decf transaction-level))
-	  (execute-command "COMMIT" :database database)
-	  (setf autocommit (previous-autocommit transaction))
+          (case (database-underlying-type database)
+            (:mssql (execute-command "COMMIT TRANSACTION" :database database))
+            (t (execute-command "COMMIT" :database database)))
+          (setf autocommit (previous-autocommit transaction))
           (map nil #'funcall (commit-hooks transaction)))
         (warn 'sql-warning
               :message
-	      (format nil "Cannot commit transaction against ~A because there is no transaction in progress."
-		      database)))))
+              (format nil "Cannot commit transaction against ~A because there is no transaction in progress."
+                      database)))))
 
 (defmethod database-abort-transaction ((database database))
   (with-slots (transaction transaction-level autocommit) database
     (if (plusp transaction-level)
         (when (zerop (decf transaction-level))
           (unwind-protect
-               (execute-command "ROLLBACK" :database database)
-	    (setf autocommit (previous-autocommit transaction))
+               (case (database-underlying-type database)
+                 (:mssql (execute-command "ROLLBACK TRANSACTION" :database database))
+                 (t (execute-command "ROLLBACK" :database database)))
+            (setf autocommit (previous-autocommit transaction))
             (map nil #'funcall (rollback-hooks transaction))))
         (warn 'sql-warning
-	      :message
-	      (format nil "Cannot abort transaction against ~A because there is no transaction in progress."
-		      database)))))
+              :message
+              (format nil "Cannot abort transaction against ~A because there is no transaction in progress."
+                      database)))))
 
 (defun mark-transaction-committed (database)
   (when (and (transaction database)
