@@ -3,7 +3,7 @@
 ;;;; File:    test-connection.lisp
 ;;;; Authors: Marcus Pearce <m.t.pearce@city.ac.uk>, Kevin Rosenberg
 ;;;; Created: 30/03/2004
-;;;; Updated: $Id: test-connection.lisp 11727 2007-06-17 19:39:07Z kevin $
+;;;; Updated: $Id$
 ;;;;
 ;;;; Tests for CLSQL database connections.
 ;;;;
@@ -36,17 +36,4 @@
      "dbname/user@hostname")
   ("hostname" "dbname" "user"))
 
-(deftest :db/1
-    (let ((inner-db-same)
-          (original-a)
-          (outer-db-unchanged))
-      (print "test-connection-spec")
-      (print *test-connection-spec*)
-      (clsql:with-database (a '*test-connection-spec* :database-type *test-connection-db-type*)
-        (setq original-a a)
-        (clsql:with-database (b '*test-connection-spec* :database-type *test-connection-db-type*)
-          (setq inner-db-same (eq a b)))
-        (setq outer-db-unchanged (eq a original-a))))
-  t t)
-
 ))
